/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.openapi;

import static org.junit.jupiter.api.Assertions.assertFalse;
import static org.junit.jupiter.api.Assertions.assertNotNull;
import static org.junit.jupiter.api.Assertions.assertTrue;

import org.apache.camel.impl.engine.DefaultClassResolver;
import org.apache.camel.model.ModelCamelContext;

import org.junit.jupiter.api.Test;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.databind.SerializationFeature;

import io.apicurio.datamodels.Library;
import io.apicurio.datamodels.openapi.models.OasDocument;

public class RestOpenApiReaderOverrideHostApiDocsTest extends RestOpenApiReaderApiDocsTest {

	private final Logger log = LoggerFactory.getLogger(getClass());

	@Override
	@Test
	public void testReaderRead() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setVersion("2.0");
		config.setHost("http:mycoolserver:8888/myapi");
		RestOpenApiReader reader = new RestOpenApiReader();

		OasDocument openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		ObjectMapper mapper = new ObjectMapper();
		mapper.enable(SerializationFeature.INDENT_OUTPUT);
		mapper.setSerializationInclusion(JsonInclude.Include.NON_NULL);
		Object dump = Library.writeNode(openApi);
		String json = mapper.writeValueAsString(dump);

		log.info(json);

		assertTrue(json.contains("\"host\" : \"http:mycoolserver:8888/myapi\""));
		assertTrue(json.contains("\"basePath\" : \"/api\""));

		assertFalse(json.contains("\"/hello/bye\""));
		assertFalse(json.contains("\"summary\" : \"To update the greeting message\""));
		assertFalse(json.contains("\"/hello/bye/{name}\""));
		assertTrue(json.contains("\"/hello/hi/{name}\""));

		context.stop();
	}

	@Override
	@Test
	public void testReaderReadV3() throws Exception {
		BeanConfig config = new BeanConfig();
		config.setHost("localhost:8080");
		config.setSchemes(new String[] {"http"});
		config.setBasePath("/api");
		config.setHost("http:mycoolserver:8888/myapi");
		RestOpenApiReader reader = new RestOpenApiReader();

		OasDocument openApi = reader.read(context, ((ModelCamelContext) context).getRestDefinitions(), config, context.getName(),
				new DefaultClassResolver());
		assertNotNull(openApi);

		ObjectMapper mapper = new ObjectMapper();
		mapper.enable(SerializationFeature.INDENT_OUTPUT);
		mapper.setSerializationInclusion(JsonInclude.Include.NON_NULL);
		Object dump = Library.writeNode(openApi);
		String json = mapper.writeValueAsString(dump);

		log.info(json);

		assertTrue(json.contains("\"url\" : \"http://http:mycoolserver:8888/myapi/api\""));

		assertFalse(json.contains("\"/hello/bye\""));
		assertFalse(json.contains("\"summary\" : \"To update the greeting message\""));
		assertFalse(json.contains("\"/hello/bye/{name}\""));
		assertTrue(json.contains("\"/hello/hi/{name}\""));

		context.stop();
	}
}
